ApexFlutterPlugin class

Constructors

ApexFlutterPlugin()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

androidId() → Future<String?>
Android androidID of device Return null on ios or permission deny
fingerprint() → Future<String?>
Android Build fingerprint of device Return null on ios or permission deny
generateRandomUuid() → Future<String?>
Android/iOS Generate random uuid v4
hashUID() → Future<String?>
Android hashUID is hash of (androidId + fingerprint) Return null on ios or permission deny
setSecureSurfaceView() → Future<bool?>