IsolateModel class

Constructors

IsolateModel(Request request, {String requestParamName = 'data', String? url, Encoding? encoding, Map<String, String>? headers, Duration? timeLimit, OnTimeout? onTimeout, bool? encrypt, bool isPrivate = false})

Properties

encoding → Encoding?
final
encrypt → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
final
isPrivate → bool
final
onTimeout → OnTimeout?
final
request → Request
final
requestParamName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeLimit ↔ Duration?
getter/setter pair
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited