ApiConfig class

Constructors

ApiConfig(String url, String publicVersion, String privateVersion, {String? publicKey, String? secretKey, bool encrypt = false, Map<String, dynamic>? defaultParameters, bool debugMode = false, Duration defaultTimeout = const Duration(seconds: 60), Duration uploadTimeout = const Duration(minutes: 5)})

Properties

debugMode ↔ bool
getter/setter pair
defaultParameters ↔ Map<String, dynamic>?
getter/setter pair
defaultTimeout → Duration
final
encrypt → bool
final
hashCode → int
The hash code for this object.
no setterinherited
privateVersion → String
final
publicKey → String?
final
publicVersion → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretKey → String?
final
uploadTimeout → Duration
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited