KeyPairs class

Constructors

KeyPairs({KeyPair? web, KeyPair? android, KeyPair? ios})

Properties

android → KeyPair?
final
hashCode → int
The hash code for this object.
no setterinherited
ios → KeyPair?
final
key → KeyPair?
no setter
publicKey → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretKey → String?
no setter
web → KeyPair?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited